@@ -1,12 +1,6 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright 2019 SoloKeys Developers
-# Copyright 2022 Nitrokey Developers
-#
-# Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
-# http://apache.org/licenses/LICENSE-2.0> or the MIT license <LICENSE-MIT or
-# http://opensource.org/licenses/MIT>, at your option. This file may not be
-# copied, modified, or distributed except according to those terms.
+# Copyright Nitrokey GmbH
+# SPDX-License-Identifier: Apache-2.0 OR MIT
 
 import logging
 import os
@@ -34,7 +28,7 @@ from pynitrokey.helpers import filter_sensitive_parameters, local_critical
 logger = logging.getLogger(__name__)
 
 
-def check_root():
+def check_root() -> None:
     if (os.name == "posix") and os.environ.get("ALLOW_ROOT") is None:
         if os.geteuid() == 0:
             print("THIS COMMAND SHOULD NOT BE RUN AS ROOT!")
@@ -56,7 +50,7 @@ def check_root():
 
 
 @click.group(context_settings={"help_option_names": ["-h", "--help"]})
-def nitropy():
+def nitropy() -> None:
     handler = logging.FileHandler(filename=LOG_FN, delay=True, encoding="utf-8")
     logging.basicConfig(format=LOG_FORMAT, level=logging.DEBUG, handlers=[handler])
 
@@ -74,8 +68,9 @@ def nitropy():
     for x in pymodules:
         logger.info(f"{x} version: {package_version(x)}")
 
+    version = package_version("pynitrokey")
     print(
-        f"Command line tool to interact with Nitrokey devices {pynitrokey.__version__}",
+        f"Command line tool to interact with Nitrokey devices {version}",
         file=sys.stderr,
     )
 
@@ -96,33 +91,38 @@ nitropy.add_command(pro)
 
 
 @click.command()
-def version():
+def version() -> None:
     """Version of pynitrokey library and tool."""
-    print(pynitrokey.__version__)
+    print(package_version("pynitrokey"))
 
 
 nitropy.add_command(version)
 
 
-def _list():
+def _list() -> None:
     from .nk3 import _list as list_nk3
     from .nkpk import _list as list_nkpk
 
-    fido2.commands["list"].callback()
-    start.commands["list"].callback()
+    list_fido2 = fido2.commands["list"].callback
+    list_start = start.commands["list"].callback
+    assert list_fido2 is not None
+    assert list_start is not None
+
+    list_fido2()
+    list_start()
     list_nk3()
     list_nkpk()
     # TODO add other handled models
 
 
 @click.command()
-def list():
+def list() -> None:
     """List Nitrokey devices (in firmware or bootloader mode)"""
     _list()
 
 
 @click.command(hidden=True)
-def ls():
+def ls() -> None:
     warnings.warn("The ls command is deprecated. Please use list instead.")
     _list()
 
